Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(601)

Unified Diff: webkit/browser/fileapi/file_system_operation_runner.h

Issue 21370003: Rename fileapi::LocalFileSystemOperation to FileSystemOperationImpl. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/browser/fileapi/file_system_operation_runner.h
diff --git a/webkit/browser/fileapi/file_system_operation_runner.h b/webkit/browser/fileapi/file_system_operation_runner.h
index 2c5389b373382ed8ef22239dd68e0926833fcbcb..67f30b89b1712f1af0e05bb23e99d3cf877b0759 100644
--- a/webkit/browser/fileapi/file_system_operation_runner.h
+++ b/webkit/browser/fileapi/file_system_operation_runner.h
@@ -34,7 +34,7 @@ class FileSystemContext;
//
// Some operations (e.g. CopyInForeignFile, RemoveFile, RemoveDirectory,
// CopyFileLocal, MoveFileLocal and SyncGetPlatformPath) are only supported
// by filesystems which implement LocalFileSystemOperation.
// If they are called on other filesystems
// base::PLATFORM_FILE_ERROR_INVALID_OPERATION is returned via callback.
class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemOperationRunner
@@ -263,12 +263,12 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemOperationRunner
const base::FilePath& platform_path,
const scoped_refptr<webkit_blob::ShareableFileReference>& file_ref);
// A helper method for creating LocalFileSystemOperation for operations
// that are supported only in LocalFileSystemOperation.
// Note that this returns FileSystemOperation, so the caller needs to
// call AsLocalFileSystemOperation() (which is guaranteed to be non-null
// if this method returns without error).
- FileSystemOperation* CreateLocalFileSystemOperation(
+ FileSystemOperation* CreateFileSystemOperationImpl(
const FileSystemURL& url,
base::PlatformFileError* error);
@@ -34,7 +34,7 @@ class FileSystemContext;
// Some operations (e.g. CopyInForeignFile, RemoveFile, RemoveDirectory,
// CopyFileLocal, MoveFileLocal and SyncGetPlatformPath) are only supported
-// by filesystems which implement LocalFileSystemOperation.
+// by filesystems which implement FileSystemOperationImpl.
// If they are called on other filesystems
// base::PLATFORM_FILE_ERROR_INVALID_OPERATION is returned via callback.
@@ -263,12 +263,12 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemOperationRunner
const base::FilePath& platform_path,
const scoped_refptr<webkit_blob::ShareableFileReference>& file_ref);
- // A helper method for creating LocalFileSystemOperation for operations
- // that are supported only in LocalFileSystemOperation.
+ // A helper method for creating FileSystemOperationImpl for operations
+ // that are supported only in FileSystemOperationImpl.
// Note that this returns FileSystemOperation, so the caller needs to
@@ -263,12 +263,12 @@ class WEBKIT_STORAGE_BROWSER_EXPORT FileSystemOperationRunner
// Note that this returns FileSystemOperation, so the caller needs to
- // call AsLocalFileSystemOperation() (which is guaranteed to be non-null
+ // call AsFileSystemOperationImpl() (which is guaranteed to be non-null
// if this method returns without error).

Powered by Google App Engine
This is Rietveld 408576698